@@ -33,11 +33,7 @@ class AbstractBrowserPlugin : public QObject
 public:
     ~AbstractBrowserPlugin() = default;
     QString subsystem() const;
-    virtual void handleData(const QString &event, const QJsonObject &data);
-
-    virtual bool onLoad();
-    virtual bool onUnload();
-    virtual void onSettingsChanged(const QJsonObject &newSettings);
+    int protocolVersion() const;
 
     bool isLoaded() const;
     // FIXME this should not be public but we need to change it from main.cpp
@@ -53,12 +49,28 @@ protected:
      * Here we inform the browser of the protocol used so if we do ever changed the native API we can at least detect it on the JS side and handle it
      */
     AbstractBrowserPlugin(const QString &subsystemId, int protocolVersion, QObject *parent);
+
+    virtual void handleData(const QString &event, const QJsonObject &data);
+    virtual QJsonObject handleData(int serial, const QString &event, const QJsonObject &data);
+
+    virtual bool onLoad();
+    virtual bool onUnload();
+
+    virtual void onSettingsChanged(const QJsonObject &newSettings);
+
     void sendData(const QString &action, const QJsonObject &payload = QJsonObject());
+
+    void sendReply(int requestSerial, const QJsonObject &payload = QJsonObject());
+
     QDebug debug() const;
 
     QJsonObject settings() const;
 
+    friend class PluginManager;
+
 private:
     QString m_subsystem;
+    int m_protocolVersion;
     bool m_loaded = false;
+
 };
